You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by bo...@apache.org on 2022/12/12 16:43:53 UTC

[myfaces-tobago] branch main updated: feat: Jakarta Faces 4.0: Rename “JSF” to “Faces” (#3531)

This is an automated email from the ASF dual-hosted git repository.

bommel pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/myfaces-tobago.git


The following commit(s) were added to refs/heads/main by this push:
     new a30970eedc feat: Jakarta Faces 4.0: Rename “JSF” to “Faces” (#3531)
a30970eedc is described below

commit a30970eedc0decc3aa7dde5960d75fd95c4b52aa
Author: Bernd Bohmann <bo...@apache.org>
AuthorDate: Mon Dec 12 17:43:46 2022 +0100

    feat: Jakarta Faces 4.0: Rename “JSF” to “Faces” (#3531)
    
    * feat: Jakarta Faces 4.0: Rename “JSF” to “Faces”
    https://github.com/jakartaee/faces/issues/1552
    
    * feat: Jakarta Faces 4.0: Rename “JSF” to “Faces”
    https://github.com/jakartaee/faces/issues/1552
---
 .../myfaces/tobago/example/demo/info/Activity.java | 14 +++----
 .../tobago/example/demo/info/ActivityList.java     |  4 +-
 .../example/demo/info/ActivityPhaseListener.java   |  2 +-
 .../src/main/ts/demo-inspect.ts                    |  2 +-
 .../tobago-example-demo/src/main/ts/demo-test.ts   |  2 +-
 .../000-intro/93-server-info/Server_Info.xhtml     |  2 +-
 .../src/main/webapp/js/demo-inspect.js             |  2 +-
 .../src/main/webapp/js/demo-inspect.js.map         |  2 +-
 .../src/main/webapp/js/demo-test.js                |  2 +-
 .../src/main/webapp/js/demo-test.js.map            |  2 +-
 .../tobago-example-demo/src/main/webapp/js/demo.js |  4 +-
 .../src/main/webapp/js/demo.js.map                 |  2 +-
 .../tobago-example-demo/src/main/webapp/main.xhtml |  2 +-
 .../tobago-theme-standard/src/main/js/tobago.js    |  4 +-
 .../src/main/js/tobago.js.map                      |  2 +-
 .../src/main/ts/{jsf.d.ts => faces.d.ts}           |  6 +--
 .../src/main/ts/tobago-behavior.ts                 |  2 +-
 .../src/main/ts/tobago-page.ts                     | 46 +++++++++++-----------
 .../src/main/ts/tobago-reload.ts                   |  2 +-
 .../src/main/ts/tobago-sheet.ts                    | 12 +++---
 .../src/main/ts/tobago-suggest.ts                  |  4 +-
 .../src/main/ts/tobago-tree-node.ts                |  2 +-
 tobago-theme/tsconfig.json                         |  2 +-
 23 files changed, 62 insertions(+), 62 deletions(-)

diff --git a/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/info/Activity.java b/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/info/Activity.java
index 61a373c1c2..ba8cc66d92 100644
--- a/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/info/Activity.java
+++ b/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/info/Activity.java
@@ -30,7 +30,7 @@ public class Activity implements Serializable {
 
   private Date creationDate;
 
-  private int jsfRequest;
+  private int facesRequest;
 
   private int ajaxRequest;
 
@@ -39,8 +39,8 @@ public class Activity implements Serializable {
     this.creationDate = new Date(session.getCreationTime());
   }
 
-  public void executeJsfRequest() {
-    jsfRequest++;
+  public void executeFacesRequest() {
+    facesRequest++;
   }
 
   public void executeAjaxRequest() {
@@ -63,12 +63,12 @@ public class Activity implements Serializable {
     this.creationDate = creationDate;
   }
 
-  public int getJsfRequest() {
-    return jsfRequest;
+  public int getFacesRequest() {
+    return facesRequest;
   }
 
-  public void setJsfRequest(final int jsfRequest) {
-    this.jsfRequest = jsfRequest;
+  public void setFacesRequest(final int facesRequest) {
+    this.facesRequest = facesRequest;
   }
 
   public int getAjaxRequest() {
diff --git a/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/info/ActivityList.java b/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/info/ActivityList.java
index 0a2f85b81e..47d338b86a 100644
--- a/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/info/ActivityList.java
+++ b/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/info/ActivityList.java
@@ -56,10 +56,10 @@ public class ActivityList implements Serializable {
     return new ArrayList<>(data.values());
   }
 
-  public void executeJsfRequest(final String sessionId) {
+  public void executeFacesRequest(final String sessionId) {
     final Activity activity = data.get(sessionId);
     if (activity != null) {
-      activity.executeJsfRequest();
+      activity.executeFacesRequest();
     } else {
       LOG.error("Ignoring sessionId='{}'", sessionId);
     }
diff --git a/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/info/ActivityPhaseListener.java b/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/info/ActivityPhaseListener.java
index 3a6c4ee3a8..2b9e5e09a5 100644
--- a/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/info/ActivityPhaseListener.java
+++ b/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/info/ActivityPhaseListener.java
@@ -56,7 +56,7 @@ public class ActivityPhaseListener implements PhaseListener {
       activityList.executeAjaxRequest(sessionId);
     } else {
       LOG.debug("Normal request for sessionId='{}'", sessionId);
-      activityList.executeJsfRequest(sessionId);
+      activityList.executeFacesRequest(sessionId);
     }
   }
 
diff --git a/tobago-example/tobago-example-demo/src/main/ts/demo-inspect.ts b/tobago-example/tobago-example-demo/src/main/ts/demo-inspect.ts
index 284feaad75..0ae0580c8e 100644
--- a/tobago-example/tobago-example-demo/src/main/ts/demo-inspect.ts
+++ b/tobago-example/tobago-example-demo/src/main/ts/demo-inspect.ts
@@ -58,6 +58,6 @@ class DemoInspect {
 
 document.addEventListener("DOMContentLoaded", function (event: Event): void {
   let element = document.documentElement; // XXX fixme
-  // XXX init areas after JSF AJAX update not implemented yet!
+  // XXX init areas after Faces AJAX update not implemented yet!
   DemoInspect.initInspect(element); //TODO fix inspection
 });
diff --git a/tobago-example/tobago-example-demo/src/main/ts/demo-test.ts b/tobago-example/tobago-example-demo/src/main/ts/demo-test.ts
index 1f75b69966..d05abaa8cd 100644
--- a/tobago-example/tobago-example-demo/src/main/ts/demo-test.ts
+++ b/tobago-example/tobago-example-demo/src/main/ts/demo-test.ts
@@ -41,7 +41,7 @@ class DemoTest {
 
 document.addEventListener("DOMContentLoaded", function (event: Event): void {
   let element = document.documentElement; // XXX fixme
-// XXX init areas after JSF AJAX update not implemented yet!
+// XXX init areas after Faces AJAX update not implemented yet!
   DemoTest.initTestLinks(element);
   DemoTest.initTestFrame(element);
 });
diff --git a/tobago-example/tobago-example-demo/src/main/webapp/content/000-intro/93-server-info/Server_Info.xhtml b/tobago-example/tobago-example-demo/src/main/webapp/content/000-intro/93-server-info/Server_Info.xhtml
index b23ed71869..3feb69a6d1 100644
--- a/tobago-example/tobago-example-demo/src/main/webapp/content/000-intro/93-server-info/Server_Info.xhtml
+++ b/tobago-example/tobago-example-demo/src/main/webapp/content/000-intro/93-server-info/Server_Info.xhtml
@@ -103,7 +103,7 @@
           <tc:out value="#{activity.creationDate}" labelLayout="skip"/>
         </tc:column>
         <tc:column label="Jsf Request Count">
-          <tc:out value="#{activity.jsfRequest}" labelLayout="skip"/>
+          <tc:out value="#{activity.facesRequest}" labelLayout="skip"/>
         </tc:column>
         <tc:column label="Ajax Request Count">
           <tc:out value="#{activity.ajaxRequest}" labelLayout="skip"/>
diff --git a/tobago-example/tobago-example-demo/src/main/webapp/js/demo-inspect.js b/tobago-example/tobago-example-demo/src/main/webapp/js/demo-inspect.js
index 1274a702ec..02096eacc2 100644
--- a/tobago-example/tobago-example-demo/src/main/webapp/js/demo-inspect.js
+++ b/tobago-example/tobago-example-demo/src/main/webapp/js/demo-inspect.js
@@ -48,7 +48,7 @@ class DemoInspect {
 }
 document.addEventListener("DOMContentLoaded", function (event) {
     let element = document.documentElement; // XXX fixme
-    // XXX init areas after JSF AJAX update not implemented yet!
+    // XXX init areas after Faces AJAX update not implemented yet!
     DemoInspect.initInspect(element); //TODO fix inspection
 });
 //# sourceMappingURL=demo-inspect.js.map
\ No newline at end of file
diff --git a/tobago-example/tobago-example-demo/src/main/webapp/js/demo-inspect.js.map b/tobago-example/tobago-example-demo/src/main/webapp/js/demo-inspect.js.map
index dfc4548f23..2cd86f51c6 100644
--- a/tobago-example/tobago-example-demo/src/main/webapp/js/demo-inspect.js.map
+++ b/tobago-example/tobago-example-demo/src/main/webapp/js/demo-inspect.js.map
@@ -1 +1 @@
-{"version":3,"file":"demo-inspect.js","sourceRoot":"","sources":["../../ts/demo-inspect.ts"],"names":[],"mappings":"AAAA;;;;;;;;;;;;;;;GAeG;AAEH,gCAAgC;AAEhC,MAAM,WAAW;IAEf,MAAM,CAAC,WAAW,CAAC,OAAoB;QAErC,KAAK,MAAM,IAAI,IAAI,OAAO,CAAC,gBAAgB,CAAC,MAAM,CAAC,EAAE;YACnD,KAAK,MAAM,EAAE,IAAI,IAAI,CAAC,gBAAgB,CAAC,IAAI,CAAC,EAAE;gBAC5C,EAAE,CAAC,UAAU,CAAC,YAAY,CAAC,QAAQ,CAAC,cAAc,CAAC,IAAI,CAAC,EAAE,EAAE,CAAC,CAAC;gBAC9D,EAAE,CAAC,UAAU,CAAC,WAAW,CAAC,EAAE,CAAC,CAAC;aAC/B;SACF;QAED,KAAK,MAAM,CA [...]
\ No newline at end of file
+{"version":3,"file":"demo-inspect.js","sourceRoot":"","sources":["../../ts/demo-inspect.ts"],"names":[],"mappings":"AAAA;;;;;;;;;;;;;;;GAeG;AAEH,gCAAgC;AAEhC,MAAM,WAAW;IAEf,MAAM,CAAC,WAAW,CAAC,OAAoB;QAErC,KAAK,MAAM,IAAI,IAAI,OAAO,CAAC,gBAAgB,CAAC,MAAM,CAAC,EAAE;YACnD,KAAK,MAAM,EAAE,IAAI,IAAI,CAAC,gBAAgB,CAAC,IAAI,CAAC,EAAE;gBAC5C,EAAE,CAAC,UAAU,CAAC,YAAY,CAAC,QAAQ,CAAC,cAAc,CAAC,IAAI,CAAC,EAAE,EAAE,CAAC,CAAC;gBAC9D,EAAE,CAAC,UAAU,CAAC,WAAW,CAAC,EAAE,CAAC,CAAC;aAC/B;SACF;QAED,KAAK,MAAM,CA [...]
\ No newline at end of file
diff --git a/tobago-example/tobago-example-demo/src/main/webapp/js/demo-test.js b/tobago-example/tobago-example-demo/src/main/webapp/js/demo-test.js
index e1b93e4b79..9b2c6def6d 100644
--- a/tobago-example/tobago-example-demo/src/main/webapp/js/demo-test.js
+++ b/tobago-example/tobago-example-demo/src/main/webapp/js/demo-test.js
@@ -36,7 +36,7 @@ class DemoTest {
 }
 document.addEventListener("DOMContentLoaded", function (event) {
     let element = document.documentElement; // XXX fixme
-    // XXX init areas after JSF AJAX update not implemented yet!
+    // XXX init areas after Faces AJAX update not implemented yet!
     DemoTest.initTestLinks(element);
     DemoTest.initTestFrame(element);
 });
diff --git a/tobago-example/tobago-example-demo/src/main/webapp/js/demo-test.js.map b/tobago-example/tobago-example-demo/src/main/webapp/js/demo-test.js.map
index 618f0588a0..46e2b11872 100644
--- a/tobago-example/tobago-example-demo/src/main/webapp/js/demo-test.js.map
+++ b/tobago-example/tobago-example-demo/src/main/webapp/js/demo-test.js.map
@@ -1 +1 @@
-{"version":3,"file":"demo-test.js","sourceRoot":"","sources":["../../ts/demo-test.ts"],"names":[],"mappings":"AAAA;;;;;;;;;;;;;;;GAeG;AAEH,gCAAgC;AAEhC,MAAM,QAAQ;IAEZ,MAAM,CAAC,aAAa,CAAC,OAAoB;QACvC,MAAM,OAAO,GAAG,QAAQ,CAAC,cAAc,CAAC,qBAAqB,CAAC,CAAC;QAC/D,IAAI,OAAO,IAAI,MAAM,CAAC,QAAQ,CAAC,cAAc,CAAC,OAAO,CAAC,EAAE;YACtD,OAAO,CAAC,SAAS,CAAC,GAAG,CAAC,QAAQ,CAAC,CAAC;SACjC;IACH,CAAC;IAED,MAAM,CAAC,aAAa,CAAC,OAAoB;QACvC,MAAM,SAAS,GAAG,QAAQ,CAAC,cAAc,CAAC,gBAAgB,CAAC,CAAC;QAC5D,IAAI,SAAS,EAA [...]
\ No newline at end of file
+{"version":3,"file":"demo-test.js","sourceRoot":"","sources":["../../ts/demo-test.ts"],"names":[],"mappings":"AAAA;;;;;;;;;;;;;;;GAeG;AAEH,gCAAgC;AAEhC,MAAM,QAAQ;IAEZ,MAAM,CAAC,aAAa,CAAC,OAAoB;QACvC,MAAM,OAAO,GAAG,QAAQ,CAAC,cAAc,CAAC,qBAAqB,CAAC,CAAC;QAC/D,IAAI,OAAO,IAAI,MAAM,CAAC,QAAQ,CAAC,cAAc,CAAC,OAAO,CAAC,EAAE;YACtD,OAAO,CAAC,SAAS,CAAC,GAAG,CAAC,QAAQ,CAAC,CAAC;SACjC;IACH,CAAC;IAED,MAAM,CAAC,aAAa,CAAC,OAAoB;QACvC,MAAM,SAAS,GAAG,QAAQ,CAAC,cAAc,CAAC,gBAAgB,CAAC,CAAC;QAC5D,IAAI,SAAS,EAA [...]
\ No newline at end of file
diff --git a/tobago-example/tobago-example-demo/src/main/webapp/js/demo.js b/tobago-example/tobago-example-demo/src/main/webapp/js/demo.js
index 2ba78926f2..3e98f90119 100644
--- a/tobago-example/tobago-example-demo/src/main/webapp/js/demo.js
+++ b/tobago-example/tobago-example-demo/src/main/webapp/js/demo.js
@@ -2199,7 +2199,7 @@
     }
     document.addEventListener("DOMContentLoaded", function (event) {
         let element = document.documentElement; // XXX fixme
-        // XXX init areas after JSF AJAX update not implemented yet!
+        // XXX init areas after Faces AJAX update not implemented yet!
         DemoInspect.initInspect(element); //TODO fix inspection
     });
 
@@ -2295,7 +2295,7 @@
     }
     document.addEventListener("DOMContentLoaded", function (event) {
         let element = document.documentElement; // XXX fixme
-        // XXX init areas after JSF AJAX update not implemented yet!
+        // XXX init areas after Faces AJAX update not implemented yet!
         DemoTest.initTestLinks(element);
         DemoTest.initTestFrame(element);
     });
diff --git a/tobago-example/tobago-example-demo/src/main/webapp/js/demo.js.map b/tobago-example/tobago-example-demo/src/main/webapp/js/demo.js.map
index 128e427ffd..2fbf58c329 100644
--- a/tobago-example/tobago-example-demo/src/main/webapp/js/demo.js.map
+++ b/tobago-example/tobago-example-demo/src/main/webapp/js/demo.js.map
@@ -1 +1 @@
-{"version":3,"file":"demo.js","sources":["demo-alert.js","demo-copy-to-clipboard.js","demo-date.js","../../../../node_modules/prismjs/prism.js","demo-highlight.js","demo-inspect.js","demo-login.js","demo-test.js"],"sourcesContent":["/*\n * Licensed to the Apache Software Foundation (ASF) under one or more\n * contributor license agreements.  See the NOTICE file distributed with\n * this work for additional information regarding copyright ownership.\n * The ASF licenses this file to You u [...]
\ No newline at end of file
+{"version":3,"file":"demo.js","sources":["demo-alert.js","demo-copy-to-clipboard.js","demo-date.js","../../../../node_modules/prismjs/prism.js","demo-highlight.js","demo-inspect.js","demo-login.js","demo-test.js"],"sourcesContent":["/*\n * Licensed to the Apache Software Foundation (ASF) under one or more\n * contributor license agreements.  See the NOTICE file distributed with\n * this work for additional information regarding copyright ownership.\n * The ASF licenses this file to You u [...]
\ No newline at end of file
diff --git a/tobago-example/tobago-example-demo/src/main/webapp/main.xhtml b/tobago-example/tobago-example-demo/src/main/webapp/main.xhtml
index c06bda727a..23f28c1d50 100644
--- a/tobago-example/tobago-example-demo/src/main/webapp/main.xhtml
+++ b/tobago-example/tobago-example-demo/src/main/webapp/main.xhtml
@@ -92,7 +92,7 @@
           <tc:out label="Theme:" value="#{themeController.localizedTheme} (#{themeController.theme.version})"/>
           <tc:out label="Locale:" value="#{localeController.localizedLocale}"/>
           <tc:out label="Requests:"
-                  value="#{activityList.values[0].jsfRequest} / AJAX: #{activityList.values[0].ajaxRequest}"/>
+                  value="#{activityList.values[0].facesRequest} / AJAX: #{activityList.values[0].ajaxRequest}"/>
         </tc:box>
       </tc:popup>
 
diff --git a/tobago-theme/tobago-theme-standard/src/main/js/tobago.js b/tobago-theme/tobago-theme-standard/src/main/js/tobago.js
index 917addb3db..e4af69d486 100644
--- a/tobago-theme/tobago-theme-standard/src/main/js/tobago.js
+++ b/tobago-theme/tobago-theme-standard/src/main/js/tobago.js
@@ -1,8 +1,8 @@
-!function(e){"function"==typeof define&&define.amd?define(e):e()}((function(){"use strict";class e extends HTMLElement{constructor(){super(),this.CssClass={SHOW:"show",COLLAPSE:"collapse",COLLAPSING:"collapsing"},this.toggleButton.addEventListener("click",this.toggleCollapse.bind(this))}connectedCallback(){this.expanded="true"===this.toggleButton.ariaExpanded}toggleCollapse(e){window.clearTimeout(this.timeout),this.expanded?(this.expanded=!1,this.navbarContent.style.height=`${this.navbar [...]
+!function(e){"function"==typeof define&&define.amd?define(e):e()}((function(){"use strict";class e extends HTMLElement{constructor(){super(),this.CssClass={SHOW:"show",COLLAPSE:"collapse",COLLAPSING:"collapsing"},this.toggleButton.addEventListener("click",this.toggleCollapse.bind(this))}connectedCallback(){this.expanded="true"===this.toggleButton.ariaExpanded}toggleCollapse(e){window.clearTimeout(this.timeout),this.expanded?(this.expanded=!1,this.navbarContent.style.height=`${this.navbar [...]
 /*!
     * Bootstrap v5.2.3 (https://getbootstrap.com/)
     * Copyright 2011-2022 The Bootstrap Authors (https://github.com/twbs/bootstrap/graphs/contributors)
     * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
     */
-const Me="transitionend",De=e=>{let t=e.getAttribute("data-bs-target");if(!t||"#"===t){let s=e.getAttribute("href");if(!s||!s.includes("#")&&!s.startsWith("."))return null;s.includes("#")&&!s.startsWith("#")&&(s=`#${s.split("#")[1]}`),t=s&&"#"!==s?s.trim():null}return t},Be=e=>{const t=De(e);return t&&document.querySelector(t)?t:null},je=e=>{const t=De(e);return t?document.querySelector(t):null},Pe=e=>{e.dispatchEvent(new Event(Me))},qe=e=>!(!e||"object"!=typeof e)&&(void 0!==e.jquery&&( [...]
+const Me="transitionend",De=e=>{let t=e.getAttribute("data-bs-target");if(!t||"#"===t){let s=e.getAttribute("href");if(!s||!s.includes("#")&&!s.startsWith("."))return null;s.includes("#")&&!s.startsWith("#")&&(s=`#${s.split("#")[1]}`),t=s&&"#"!==s?s.trim():null}return t},Be=e=>{const t=De(e);return t&&document.querySelector(t)?t:null},Pe=e=>{const t=De(e);return t?document.querySelector(t):null},qe=e=>{e.dispatchEvent(new Event(Me))},He=e=>!(!e||"object"!=typeof e)&&(void 0!==e.jquery&&( [...]
 //# sourceMappingURL=tobago.js.map
diff --git a/tobago-theme/tobago-theme-standard/src/main/js/tobago.js.map b/tobago-theme/tobago-theme-standard/src/main/js/tobago.js.map
index 0b80d222b9..089080472d 100644
--- a/tobago-theme/tobago-theme-standard/src/main/js/tobago.js.map
+++ b/tobago-theme/tobago-theme-standard/src/main/js/tobago.js.map
@@ -1 +1 @@
-{"version":3,"file":"tobago.js","sources":["../ts/tobago-bar.ts","../../../../node_modules/@popperjs/core/lib/enums.js","../../../../node_modules/@popperjs/core/lib/dom-utils/getNodeName.js","../../../../node_modules/@popperjs/core/lib/dom-utils/getWindow.js","../../../../node_modules/@popperjs/core/lib/dom-utils/instanceOf.js","../../../../node_modules/@popperjs/core/lib/modifiers/applyStyles.js","../../../../node_modules/@popperjs/core/lib/utils/getBasePlacement.js","../../../../node_m [...]
\ No newline at end of file
+{"version":3,"file":"tobago.js","sources":["../ts/tobago-bar.ts","../../../../node_modules/@popperjs/core/lib/enums.js","../../../../node_modules/@popperjs/core/lib/dom-utils/getNodeName.js","../../../../node_modules/@popperjs/core/lib/dom-utils/getWindow.js","../../../../node_modules/@popperjs/core/lib/dom-utils/instanceOf.js","../../../../node_modules/@popperjs/core/lib/modifiers/applyStyles.js","../../../../node_modules/@popperjs/core/lib/utils/getBasePlacement.js","../../../../node_m [...]
\ No newline at end of file
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-behavior.ts b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-behavior.ts
index 3f5a757a0b..cb4fa4faa3 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-behavior.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-behavior.ts
@@ -87,7 +87,7 @@ class Behavior extends HTMLElement {
             }
           }
         }
-        jsf.ajax.request(
+        faces.ajax.request(
             this.actionElement,
             event,
             {
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-page.ts b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-page.ts
index 19afe56117..e5a3a15873 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-page.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-page.ts
@@ -129,34 +129,34 @@ export class Page extends HTMLElement {
   }
 
   registerAjaxListener(): void {
-    jsf.ajax.addOnEvent(this.jsfResponse.bind(this));
+    faces.ajax.addOnEvent(this.facesResponse.bind(this));
   }
 
-  jsfResponse(event: EventData): void {
-    console.timeEnd("[tobago-jsf] jsf-ajax");
-    console.time("[tobago-jsf] jsf-ajax");
-    console.debug("[tobago-jsf] JSF event status: '%s'", event.status);
+  facesResponse(event: EventData): void {
+    console.timeEnd("[tobago-faces] faces-ajax");
+    console.time("[tobago-faces] faces-ajax");
+    console.debug("[tobago-faces] Faces event status: '%s'", event.status);
     if (event.status === "success") {
-      event.responseXML.querySelectorAll("update").forEach(this.jsfResponseSuccess.bind(this));
+      event.responseXML.querySelectorAll("update").forEach(this.facesResponseSuccess.bind(this));
     } else if (event.status === "complete") {
-      event.responseXML.querySelectorAll("update").forEach(this.jsfResponseComplete.bind(this));
+      event.responseXML.querySelectorAll("update").forEach(this.facesResponseComplete.bind(this));
     }
   }
 
-  jsfResponseSuccess(update: Element): void {
+  facesResponseSuccess(update: Element): void {
     const id = update.id;
     let rootNode = this.getRootNode() as ShadowRoot | Document;
     // XXX in case of "this" is tobago-page (e.g. ajax exception handling) rootNode is not set correctly???
     if (!rootNode.getElementById) {
       rootNode = document;
     }
-    console.debug("[tobago-jsf] Update after jsf.ajax success: %s", id);
+    console.debug("[tobago-faces] Update after faces.ajax success: %s", id);
   }
 
-  jsfResponseComplete(update: Element): void {
+  facesResponseComplete(update: Element): void {
     const id = update.id;
-    if (JsfParameter.isJsfId(id)) {
-      console.debug("[tobago-jsf] Update after jsf.ajax complete: #", id);
+    if (FacesParameter.isFacesId(id)) {
+      console.debug("[tobago-faces] Update after faces.ajax complete: #", id);
       const overlay = this.querySelector(`tobago-overlay[for='${id}']`);
       if (overlay) {
         overlay.remove();
@@ -214,7 +214,7 @@ document.addEventListener("tobago.init", (event: Event): void => {
   }
 });
 
-class JsfParameter {
+class FacesParameter {
 
   static VIEW_STATE = "jakarta.faces.ViewState";
   static CLIENT_WINDOW = "jakarta.faces.ClientWindow";
@@ -223,24 +223,24 @@ class JsfParameter {
   static VIEW_BODY = "jakarta.faces.ViewBody";
   static RESOURCE = "jakarta.faces.Resource";
 
-  static isJsfId(id: string): boolean {
+  static isFacesId(id: string): boolean {
     switch (id) {
-      case JsfParameter.VIEW_STATE:
-      case JsfParameter.CLIENT_WINDOW:
-      case JsfParameter.VIEW_ROOT:
-      case JsfParameter.VIEW_HEAD:
-      case JsfParameter.VIEW_BODY:
-      case JsfParameter.RESOURCE:
+      case FacesParameter.VIEW_STATE:
+      case FacesParameter.CLIENT_WINDOW:
+      case FacesParameter.VIEW_ROOT:
+      case FacesParameter.VIEW_HEAD:
+      case FacesParameter.VIEW_BODY:
+      case FacesParameter.RESOURCE:
         return false;
       default:
         return true;
     }
   }
 
-  static isJsfBody(id): boolean {
+  static isFacesBody(id): boolean {
     switch (id) {
-      case JsfParameter.VIEW_ROOT:
-      case JsfParameter.VIEW_BODY:
+      case FacesParameter.VIEW_ROOT:
+      case FacesParameter.VIEW_BODY:
         return true;
       default:
         return false;
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-reload.ts b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-reload.ts
index 269561f6a6..3383ff35f8 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-reload.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-reload.ts
@@ -44,7 +44,7 @@ class TobagoReload extends HTMLElement {
       // add new schedule
       const timeout = window.setTimeout(function (): void {
         console.debug("reloading #'%s'", componentId);
-        jsf.ajax.request(
+        faces.ajax.request(
             reloadId,
             null,
             {
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-sheet.ts b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-sheet.ts
index e30807c041..b95f7aef21 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-sheet.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-sheet.ts
@@ -398,8 +398,8 @@ export class Sheet extends HTMLElement {
       for (let i = 0; i < updates.length; i++) {
         const update = updates[i];
         const id = update.getAttribute("id");
-        if (id.indexOf(":") > -1) { // is a JSF element id, but not a technical id from the framework
-          console.debug(`[tobago-sheet][complete] Update after jsf.ajax complete: #${id}`); // @DEV_ONLY
+        if (id.indexOf(":") > -1) { // is a Faces element id, but not a technical id from the framework
+          console.debug(`[tobago-sheet][complete] Update after faces.ajax complete: #${id}`); // @DEV_ONLY
 
           const sheet = document.getElementById(id);
           sheet.id = `${id}::lazy-temporary`;
@@ -414,8 +414,8 @@ export class Sheet extends HTMLElement {
       for (let i = 0; i < updates.length; i++) {
         const update = updates[i];
         const id = update.getAttribute("id");
-        if (id.indexOf(":") > -1) { // is a JSF element id, but not a technical id from the framework
-          console.debug(`[tobago-sheet][success] Update after jsf.ajax complete: #${id}`); // @DEV_ONLY
+        if (id.indexOf(":") > -1) { // is a Faces element id, but not a technical id from the framework
+          console.debug(`[tobago-sheet][success] Update after faces.ajax complete: #${id}`); // @DEV_ONLY
 
           // sync the new rows into the sheet
           const sheetLoader = document.getElementById(id);
@@ -457,7 +457,7 @@ Type: ${data.type}`);
     const renderIds = this.id;
     const lazy = this.lazy;
 
-    jsf.ajax.request(
+    faces.ajax.request(
         source.id,
         null,
         {
@@ -675,7 +675,7 @@ Type: ${data.type}`);
     if (output.innerHTML !== input.value) {
       console.debug("Reloading sheet '%s' old value='%s' new value='%s'", this.id, output.innerHTML, input.value);
       output.innerHTML = input.value;
-      jsf.ajax.request(
+      faces.ajax.request(
           input.id,
           null,
           {
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-suggest.ts b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-suggest.ts
index bfce3c92c0..26acdd6f6c 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-suggest.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-suggest.ts
@@ -61,7 +61,7 @@ export class Suggest {
           if (this.update) {
             this.resolve = resolve;
             const suggestId = this.suggest.id;
-            jsf.ajax.request(suggestId, null, {
+            faces.ajax.request(suggestId, null, {
               "jakarta.faces.behavior.event": "suggest",
               execute: suggestId,
               render: suggestId
@@ -92,7 +92,7 @@ export class Suggest {
   }
 
   private registerAjaxListener(): void {
-    jsf.ajax.addOnEvent(this.resolvePromise.bind(this));
+    faces.ajax.addOnEvent(this.resolvePromise.bind(this));
   }
 
   private resolvePromise(event: EventData): void {
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-tree-node.ts b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-tree-node.ts
index 8c269420d6..8e834da1eb 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-tree-node.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-tree-node.ts
@@ -75,7 +75,7 @@ export class TreeNode extends HTMLElement {
   }
 
   private ajax(event: Event, renderTree: boolean): void {
-    jsf.ajax.request(
+    faces.ajax.request(
         this.id,
         event,
         {
diff --git a/tobago-theme/tsconfig.json b/tobago-theme/tsconfig.json
index 0d31d7c53f..d11469ee04 100644
--- a/tobago-theme/tsconfig.json
+++ b/tobago-theme/tsconfig.json
@@ -15,7 +15,7 @@
   },
   "include": [
 //    "tobago-theme-standard/src/main/ts/tobago-all.ts",
-//    "tobago-theme-standard/src/main/ts/jsf.d.ts",
+//    "tobago-theme-standard/src/main/ts/faces.d.ts",
     "tobago-theme-standard/src/main/ts/*.ts"
   ],
   "exclude": [
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/jsf.d.ts b/tobago-theme/tobago-theme-standard/src/main/ts/faces.d.ts
similarity index 92%
rename from tobago-theme/tobago-theme-standard/src/main/ts/jsf.d.ts
rename to tobago-theme/tobago-theme-standard/src/main/ts/faces.d.ts
index caf21ba569..2de6a7d5e7 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/jsf.d.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/faces.d.ts
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
 // JSF JS declarations. It's the best of what I've found out - with no guaranty!
 
 declare type Context = {
   [key: string]: any;
@@ -43,9 +43,9 @@ declare interface ErrorData {
   responseCode: number;
 }
 
-declare let jsf: jsf;
+declare let faces: faces;
 
-interface jsf {
+interface faces {
   ajax: {
     request(
         element: Element,
@@ -15,7 +15,7 @@
  */
 
-// JSF JS declarations. It's the best of what I've found out - with no guaranty!
+// Faces JS declarations. It's the best of what I've found out - with no guaranty!
 
 declare type Context = {